@@ -1,7 +1,14 @@
 from math import ceil
 
 from PySide6.QtCore import QPoint, QRect, QSize
-from PySide6.QtGui import QBrush, QMouseEvent, QPainter, QPaintEvent, QResizeEvent
+from PySide6.QtGui import (
+    QBrush,
+    QCloseEvent,
+    QMouseEvent,
+    QPainter,
+    QPaintEvent,
+    QResizeEvent,
+)
 from PySide6.QtWidgets import QComboBox, QLabel, QLayout, QStatusBar, QToolBar, QWidget
 
 from foundry import icon
@@ -62,6 +69,10 @@ class BlockViewer(CustomChildWindow):
 
         return
 
+    def closeEvent(self, event: QCloseEvent):
+        self.toolbar.close()
+        super().closeEvent(event)
+
     @property
     def object_set(self):
         return self._object_set
@@ -140,7 +151,7 @@ class BlockBank(QWidget):
         self.setFixedSize(new_size)
 
     def mouseMoveEvent(self, event: QMouseEvent):
-        x, y = event.position().toTuple()
+        x, y = event.pos().toTuple()
 
         block_length = Block.WIDTH * self.zoom
 
